@@ -20,10 +20,38 @@ class TreeMeasure(timewise.Measure):
         self._offset = None
         self._barline_style = None
 
+    # properties
+
     @property
-    def __name__(self):
-        index = self.up.get_children_by_type(self.__class__).index(self)
-        return str(index + 1)
+    def barline_style(self):
+        return self._barline_style
+
+    @property
+    def next(self):
+        return self.next_sibling
+
+    @property
+    def offset(self):
+        if self._offset is None:
+            self.update_offset()
+        return self._offset
+
+    @property
+    def previous(self):
+        if not self.up:
+            return None
+        index = self.up.get_children_by_type(TreeMeasure).index(self)
+        if index == 0:
+            return None
+        return self.up.get_children_by_type(TreeMeasure)[index - 1]
+
+    @property
+    def quarter_duration(self):
+        output = 0
+        for time_signature in self.time.get_time_signatures():
+            (beats, beat_type) = time_signature
+            output += beats.value / beat_type.value * 4
+        return Fraction(output).limit_denominator(10000)
 
     @property
     def time(self):
@@ -44,17 +72,43 @@ class TreeMeasure(timewise.Measure):
             self._time = None
 
     @property
-    def quarter_duration(self):
-        output = 0
-        for time_signature in self.time.get_time_signatures():
-            (beats, beat_type) = time_signature
-            output += beats.value / beat_type.value * 4
-        return Fraction(output).limit_denominator(10000)
+    def __name__(self):
+        index = self.up.get_children_by_type(self.__class__).index(self)
+        return str(index + 1)
 
-    @property
-    def barline_style(self):
-        return self._barline_style
+    # // private methods
 
+    def _add_page_one(self):
+        score = self.up
+
+        first_part = score.get_measure(1).get_part(1)
+
+        first_part.get_children_by_type(TreePart)
+        try:
+            print_ = first_part.get_children_by_type(Print)[0]
+        except IndexError:
+            print_ = first_part.add_child(Print())
+        print_.page_number = '1'
+
+    # // public methods
+    # gets
+
+    def get_part(self, number):
+        return self.get_children_by_type(TreePart)[number - 1]
+
+    def get_part_with_id(self, id):
+        try:
+            return [part for part in self.get_children_by_type(TreePart) if part.id == id][0]
+        except IndexError:
+            raise AttributeError('measure {} has no part with id {}'.format(self, id))
+
+    def get_beats(self):
+        output = []
+        for part in self.get_children_by_type(TreePart):
+            output.extend(part.get_beats())
+        return output
+
+    # sets
     def set_barline_style(self, value):
         if value:
             for part in self.get_children_by_type(TreePart):
@@ -71,51 +125,7 @@ class TreeMeasure(timewise.Measure):
 
         self._barline_style = value
 
-    def show_time_signature(self):
-        for part in self.get_children_by_type(TreePart):
-            part.get_children_by_type(Attributes)[0].add_child(self.time)
-
-    def hide_time_signature(self):
-        part = self.get_children_by_type(TreePart)[0]
-        if self.time in part.get_children_by_type(Attributes)[0].get_children():
-            part.get_children_by_type(Attributes)[0].remove_child(self.time)
-
-    def get_part(self, number):
-        return self.get_children_by_type(TreePart)[number - 1]
-
-    def get_beats(self):
-        output = []
-        for part in self.get_children_by_type(TreePart):
-            output.extend(part.get_beats())
-        return output
-
-    @property
-    def previous(self):
-        if not self.up:
-            return None
-        index = self.up.get_children_by_type(TreeMeasure).index(self)
-        if index == 0:
-            return None
-        return self.up.get_children_by_type(TreeMeasure)[index - 1]
-
-    def update_offset(self):
-        if self.previous:
-            output = self.previous.offset + self.previous.quarter_duration
-            self._offset = output
-        else:
-            self._offset = 0
-
-    def _add_page_one(self):
-        score = self.up
-
-        first_part = score.get_measure(1).get_part(1)
-
-        first_part.get_children_by_type(TreePart)
-        try:
-            print_ = first_part.get_children_by_type(Print)[0]
-        except IndexError:
-            print_ = first_part.add_child(Print())
-        print_.page_number = '1'
+    # adds
 
     def add_page_break(self):
 
@@ -164,12 +174,24 @@ class TreeMeasure(timewise.Measure):
 
             sd.value = value
 
-    @property
-    def offset(self):
-        if self._offset is None:
-            self.update_offset()
-        return self._offset
+    # others
+    def show_time_signature(self):
+        for part in self.get_children_by_type(TreePart):
+            part.get_children_by_type(Attributes)[0].add_child(self.time)
 
+    def hide_time_signature(self):
+        part = self.get_children_by_type(TreePart)[0]
+        if self.time in part.get_children_by_type(Attributes)[0].get_children():
+            part.get_children_by_type(Attributes)[0].remove_child(self.time)
+
+    def update_offset(self):
+        if self.previous:
+            output = self.previous.offset + self.previous.quarter_duration
+            self._offset = output
+        else:
+            self._offset = 0
+
+    # // copy
     def __copy__(self):
         time = self.time.__copy__()
         new_measure = TreeMeasure(time)
