@@ -1,5 +1,4 @@
 import os
-from unittest import TestCase
 
 from quicktions import Fraction
 
@@ -7,12 +6,13 @@ from musicscore.musicstream.streamvoice import SimpleFormat
 from musicscore.musictree.treechord import TreeChord
 from musicscore.musictree.treechordflags3 import TreeChordFlag3
 from musicscore.musictree.treescoretimewise import TreeScoreTimewise
+from musicxmlunittest import XMLTestCase
 from tests.score_templates.xml_test_score import TestScore
 
 path = str(os.path.abspath(__file__).split('.')[0])
 
 
-class Test(TestCase):
+class Test(XMLTestCase):
     def setUp(self):
         self.score = TreeScoreTimewise()
         self.score.add_measure()
@@ -38,7 +38,8 @@ class Test(TestCase):
             chord = TreeChord(midi, quarter_duration=0.5)
             chord.add_lyric(midi)
             self.score.add_chord(measure_number, 1, chord)
-            remaining_duration = self.score.get_measure(measure_number).get_part(1).get_voice(1).remaining_duration
+            remaining_duration = self.score.get_measure(measure_number).get_part(1).get_staff(1).get_voice(
+                1).remaining_duration
             if remaining_duration == 0:
                 self.score.add_measure()
                 measure_number += 1
@@ -54,7 +55,8 @@ class Test(TestCase):
             chord = TreeChord(midi, quarter_duration=0.5)
             chord.add_lyric([m.value for m in chord.midis])
             self.score.add_chord(measure_number, 1, chord)
-            remaining_duration = self.score.get_measure(measure_number).get_part(1).get_voice(1).remaining_duration
+            remaining_duration = self.score.get_measure(measure_number).get_part(1).get_staff(1).get_voice(
+                1).remaining_duration
             if remaining_duration == 0:
                 self.score.add_measure()
                 measure_number += 1
@@ -66,16 +68,16 @@ class Test(TestCase):
     def test_4(self):
         simpleformat = SimpleFormat(midis=list(range(60, 68)))
         voice = simpleformat.to_stream_voice(2)
-        voice.add_to_score(self.score, 1, 1)
-        result_path = path + '_test_4'
+        voice.add_to_score(self.score)
+        xml_path = path + '_test_4.xml'
         self.score.accidental_mode = 'modern'
-        self.score.write(result_path)
-        TestScore().assert_template(result_path=result_path)
+        self.score.write(xml_path)
+        self.assertCompareFiles(xml_path)
 
     def test_5(self):
         simpleformat = SimpleFormat(midis=[71.5, 71.5, 72, 72, 71.5, 71.5], quarter_durations=6 * [0.5])
         voice = simpleformat.to_stream_voice(1)
-        voice.add_to_score(self.score, 1, 1)
+        voice.add_to_score(self.score)
         result_path = path + '_test_5'
         self.score.accidental_mode = 'normal'
         self.score.write(result_path)
@@ -89,7 +91,7 @@ class Test(TestCase):
         simpleformat = SimpleFormat(midis=midis, quarter_durations=durations)
         simpleformat.auto_clef()
         voice = simpleformat.to_stream_voice(1)
-        voice.add_to_score(self.score, 1, 1)
+        voice.add_to_score(self.score)
         result_path = path + '_test_6'
         self.score.max_division = 7
         self.score.accidental_mode = 'modern'
@@ -144,3 +146,13 @@ class Test(TestCase):
         xml_path = path + '_test_9.xml'
         self.score.write(xml_path)
         TestScore().assert_template(xml_path)
+
+    # def test_10(self):
+    #     v1 = SimpleFormat(quarter_durations=[2, 2], midis=[72, 73])
+    #     v2 = SimpleFormat(quarter_durations=[2, 2], midis=[60, 61])
+    #     v1.to_stream_voice(1).add_to_score(self.score)
+    #     v2.to_stream_voice(2).add_to_score(self.score)
+    #
+    #     xml_path = path + '_test_10.xml'
+    #     self.score.write(xml_path)
+    #     self.assertCompareFiles(xml_path)
