@@ -25,7 +25,7 @@ class Test(TestCase):
         sf.chords[7].add_clef(HIGH_TREBLE_CLEF)
 
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
 
         result_path = path + '_test_1'
         self.score.write(path=result_path)
