@@ -15,7 +15,7 @@ class Test(TestCase):
     def test_1(self):
         sf = SimpleFormat(quarter_durations=[1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 10])
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
         self.score.finish()
 
         partwise = self.score.to_partwise()
